==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ta-IN/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'நாட்களில்',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'சொத்துக்கள் அறிக்கை முடிவடைகிறது.',
    'Expiring_Licenses_Report' => 'காலாவதி உரிமைகள் அறிக்கை.',
    'Item_Request_Canceled' => 'பொருள் கோரிக்கை ரத்து செய்யப்பட்டது',
    'Item_Requested' => 'பொருள் கோரியது',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'குறைவான சரக்கு அறிக்கை',
    'a_user_canceled' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படி கோரிக்கையை ரத்து செய்துள்ளார்',
    'a_user_requested' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படியைக் கோரியுள்ளார்',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'துணை பெயர்',
    'additional_notes' => 'Additional Notes',
    'admin_has_created' => 'ஒரு வலைத்தளம் உங்களுக்கு ஒரு கணக்கை உருவாக்கியுள்ளது: இணையத்தளம்.',
    'asset' => 'சொத்து',
    'asset_name' => 'சொத்து பெயர்',
    'asset_requested' => 'சொத்து கோரப்பட்டது',
    'asset_tag' => 'சொத்து டேக்',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'ஒதுக்கப்படும்',
    'best_regards' => 'சிறந்த வாழ்த்துக்கள்,',
    'canceled' => 'Canceled',
    'checkin_date' => 'சரி தேதி',
    'checkout_date' => 'புதுப்பிப்பு தேதி',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'நீங்கள் இணைப்பு பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'click_on_the_link_asset' => 'நீங்கள் சொத்தை பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'click_to_confirm' => 'உங்கள்: இணைய கணக்கை உறுதிப்படுத்த பின்வரும் இணைப்பை கிளிக் செய்யவும்:',
    'current_QTY' => 'தற்போதைய QTY',
    'days' => 'நாட்களில்',
    'expecting_checkin_date' => 'எதிர்பார்த்த செக்கின் தேதி',
    'expires' => 'காலாவதியாகிறது',
    'hello' => 'வணக்கம்',
    'hi' => 'வணக்கம்',
    'i_have_read' => 'நான் பயன்பாட்டு விதிமுறைகளைப் படித்து ஒப்புக்கொள்கிறேன், இந்த உருப்படியைப் பெற்றுள்ளேன்.',
    'inventory_report' => 'Inventory Report',
    'item' => 'பொருள்',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'தயவுசெய்து புதுப்பிக்க பின்வரும் இணைப்பை கிளிக் செய்யவும்: உங்கள் இணைய கடவுச்சொல்:',
    'login' => 'உள் நுழை:',
    'login_first_admin' => 'கீழே உள்ள சான்றுகளை பயன்படுத்தி உங்கள் புதிய Snipe-IT நிறுவலுக்கு உள்நுழையவும்:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'குறைந்தது QTY',
    'name' => 'பெயர்',
    'new_item_checked' => 'உங்கள் பெயரில் ஒரு புதிய உருப்படி சோதிக்கப்பட்டது, விவரங்கள் கீழே உள்ளன.',
    'notes' => 'குறிப்புக்கள்',
    'password' => 'கடவுச்சொல்',
    'password_reset' => 'கடவுச்சொல்லை மீட்டமை',
    'read_the_terms' => 'கீழே உள்ள விதிமுறைகளை தயவுசெய்து படித்துப் பாருங்கள்.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'கோரப்பட்டது',
    'reset_link' => 'உங்கள் கடவுச்சொல்லை மீட்டமை இணைப்பு',
    'reset_password' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க இங்கே கிளிக் செய்க:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'சீரியல்',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'சப்ளையர்',
    'tag' => 'டேக்',
    'test_email' => 'ஸ்னாப்-டி இருந்து மின்னஞ்சல் சோதனை',
    'test_mail_text' => 'இது Snipe-IT சொத்து முகாமைத்துவ கணினியிலிருந்து ஒரு சோதனை ஆகும். இதை நீங்கள் பெற்றிருந்தால், மின்னஞ்சல் வேலை செய்கிறது :)',
    'the_following_item' => 'பின்வரும் உருப்படி பின்வருமாறு சரிபார்க்கப்பட்டது:',
    'to_reset' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க, இந்த படிவத்தை பூர்த்தி செய்க:',
    'type' => 'வகை',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'பயனர்',
    'username' => 'பயனர்பெயர்',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'வரவேற்பு: பெயர்',
    'welcome_to' => 'வரவேற்கிறோம்: வலை!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'உங்கள் கத்தரி-ஐடி சான்றுகள்',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ta-IN/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'நாட்களில்',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'சொத்துக்கள் அறிக்கை முடிவடைகிறது.',
    'Expiring_Licenses_Report' => 'காலாவதி உரிமைகள் அறிக்கை.',
    'Item_Request_Canceled' => 'பொருள் கோரிக்கை ரத்து செய்யப்பட்டது',
    'Item_Requested' => 'பொருள் கோரியது',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'குறைவான சரக்கு அறிக்கை',
    'a_user_canceled' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படி கோரிக்கையை ரத்து செய்துள்ளார்',
    'a_user_requested' => 'வலைத்தளத்தில் பயனர் ஒரு உருப்படியைக் கோரியுள்ளார்',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'துணை பெயர்',
    'additional_notes' => 'Additional Notes',
    'admin_has_created' => 'ஒரு வலைத்தளம் உங்களுக்கு ஒரு கணக்கை உருவாக்கியுள்ளது: இணையத்தளம்.',
    'asset' => 'சொத்து',
    'asset_name' => 'சொத்து பெயர்',
    'asset_requested' => 'சொத்து கோரப்பட்டது',
    'asset_tag' => 'சொத்து டேக்',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'ஒதுக்கப்படும்',
    'best_regards' => 'சிறந்த வாழ்த்துக்கள்,',
    'canceled' => 'Canceled',
    'checkin_date' => 'சரி தேதி',
    'checkout_date' => 'புதுப்பிப்பு தேதி',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'நீங்கள் இணைப்பு பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'click_on_the_link_asset' => 'நீங்கள் சொத்தை பெற்றுள்ளீர்கள் என்பதை உறுதிப்படுத்த கீழே உள்ள இணைப்பைக் கிளிக் செய்க.',
    'click_to_confirm' => 'உங்கள்: இணைய கணக்கை உறுதிப்படுத்த பின்வரும் இணைப்பை கிளிக் செய்யவும்:',
    'current_QTY' => 'தற்போதைய QTY',
    'days' => 'நாட்களில்',
    'expecting_checkin_date' => 'எதிர்பார்த்த செக்கின் தேதி',
    'expires' => 'காலாவதியாகிறது',
    'hello' => 'வணக்கம்',
    'hi' => 'வணக்கம்',
    'i_have_read' => 'நான் பயன்பாட்டு விதிமுறைகளைப் படித்து ஒப்புக்கொள்கிறேன், இந்த உருப்படியைப் பெற்றுள்ளேன்.',
    'inventory_report' => 'Inventory Report',
    'item' => 'பொருள்',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'தயவுசெய்து புதுப்பிக்க பின்வரும் இணைப்பை கிளிக் செய்யவும்: உங்கள் இணைய கடவுச்சொல்:',
    'login' => 'உள் நுழை',
    'login_first_admin' => 'கீழே உள்ள சான்றுகளை பயன்படுத்தி உங்கள் புதிய Snipe-IT நிறுவலுக்கு உள்நுழையவும்:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'குறைந்தது QTY',
    'name' => 'பெயர்',
    'new_item_checked' => 'உங்கள் பெயரில் ஒரு புதிய உருப்படி சோதிக்கப்பட்டது, விவரங்கள் கீழே உள்ளன.',
    'notes' => 'குறிப்புக்கள்',
    'password' => 'கடவுச்சொல்',
    'password_reset' => 'கடவுச்சொல்லை மீட்டமை',
    'read_the_terms' => 'கீழே உள்ள விதிமுறைகளை தயவுசெய்து படித்துப் பாருங்கள்.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'கோரப்பட்டது',
    'reset_link' => 'உங்கள் கடவுச்சொல்லை மீட்டமை இணைப்பு',
    'reset_password' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க இங்கே கிளிக் செய்க:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'சீரியல்',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'சப்ளையர்',
    'tag' => 'டேக்',
    'test_email' => 'ஸ்னாப்-டி இருந்து மின்னஞ்சல் சோதனை',
    'test_mail_text' => 'இது Snipe-IT சொத்து முகாமைத்துவ கணினியிலிருந்து ஒரு சோதனை ஆகும். இதை நீங்கள் பெற்றிருந்தால், மின்னஞ்சல் வேலை செய்கிறது :)',
    'the_following_item' => 'பின்வரும் உருப்படி பின்வருமாறு சரிபார்க்கப்பட்டது:',
    'to_reset' => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க, இந்த படிவத்தை பூர்த்தி செய்க:',
    'type' => 'வகை',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'பயனர்',
    'username' => 'பயனர்பெயர்',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'வரவேற்பு: பெயர்',
    'welcome_to' => 'வரவேற்கிறோம்: வலை!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'உங்கள் கத்தரி-ஐடி சான்றுகள்',
    'mail_sent' => 'Mail sent successfully!',
];
